translate.storage.statsdb.Record

Package translate :: Package storage :: Module statsdb :: Class Record |
[hide private]
[frames] | no frames]

# Class Record

source code

Instance Methods | [hide private]
__init__(self, record_keys, record_values=None, compute_derived_values=lambda x: x) | source code
to_tuple(self) | source code
__add__(self, other) | source code
__sub__(self, other) | source code
as_string_for_db(self) | source code
Inherited from `UserDict.UserDict`: `__cmp__`, `__contains__`, `__delitem__`, `__getitem__`, `__len__`, `__repr__`, `__setitem__`, `clear`, `copy`, `get`, `has_key`, `items`, `iteritems`, `iterkeys`, `itervalues`, `keys`, `pop`, `popitem`, `setdefault`, `update`, `values`

Class Methods | [hide private]
Inherited from `UserDict.UserDict`: `fromkeys`

Method Details | [hide private]

### __init__(self, record_keys, record_values=None, compute_derived_values=lambda x: x) (Constructor) | source code
Overrides: UserDict.UserDict.__init__